****************
Acknowledgements
****************

The MolSSI ``zenopy`` was developed by Mohammad Mostafanejad at the MolSSI |molssi|,
which is funded in part by the National Science Foundation |nsf| under grant awards
OAC-1547580 and CHE-2136142. This work could not have been done without their support!

.. |molssi| image:: images/acknowledgements/MolSSI.jpg
                    :alt: MolSSI logo
.. |nsf| image:: images/acknowledgements/NSF_4-Color_bitmap_Logo.png
                 :alt: NSF logo
